#
# spec file for package python-imageio
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# Tests don't work without internet
%bcond_with tests
Name:           python-imageio
Version:        2.3.0
Release:        bp153.1.18
Summary:        Python library for reading and writing image, video, and related formats
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            http://imageio.github.io/
Source:         https://files.pythonhosted.org/packages/source/i/imageio/imageio-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  ffmpeg
BuildRequires:  libfreeimage3
BuildRequires:  python-rpm-macros
Requires:       ffmpeg
Requires:       libfreeimage3
Requires:       python-numpy
Recommends:     libfreeimageplus3
BuildArch:      noarch
%if %{with tests}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
Imageio is a Python library that provides an interface to read and
write a wide range of image data, including animated images, volumetric
data, and scientific formats.

%prep
%setup -q -n imageio-%{version}

%build
export IMAGEIO_NO_INTERNET=1
%python_build

%install
export IMAGEIO_NO_INTERNET=1
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with tests}
%check
pushd tests
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitelib}
py.test-%{$python_bin_suffix}
}
popd
%endif

%files %{python_files}
%license LICENSE
%doc CONTRIBUTORS.txt README.md
%{python_sitelib}/*
%python3_only %{_bindir}/imageio_download_bin
%python3_only %{_bindir}/imageio_remove_bin

%changelog
* Sat Apr 21 2018 arun@gmx.de
- specfile:
  * changed from zip to tar.gz on pypi
  * added binaries: imagio_{download,remove}_bin
- update to version 2.3.0:
  * Console entry points for binary downloads (by Paul Mueller).
  * Dropped support for Python 2.6, 3.2 and 3.3.
  * Reading images from a url can now also have "suffixes" like
    "?query=foo".
  * The "mimwrite()" and "mvolwrite()" functions also work with
    generators.
  * Fix rounding of float data.
  * New Lytro plugin (by Maximilian Schambach).
  * New plugin based on BSDF format (for images/volumes and series
    thereof,
  * including support for random access and streaming).
  * TIFFFILE update to latest "tifffile.py" implementation.
  * DICOM fix that could fail in the presence of a directory.
  * PILLOW improvements to API to provide same functionality as
    Scipy's "imread()".
  * PILLOW fix for Gamma correction (#302).
  * PILLOW now allows JPEG images to be read from a url.
  * PILLOW fix determining of grayscale in 1 bit paletted images.
  * FFMPEG improved device name parsing (by Dennis van Gerwen).
  * FFMPEG now allows more control of position of extra parameters.
  * FFMPEG improved parsing of fps from ffmpeg info.
  * FFMPEG reader allows has "fps" argument to force reading at a
    specific FPS.
- changes from version 2.2.0:
  * New format for grabbing screenshots (for Windows and OS X).
  * New format for grabbing image data from clipboard (Window only).
  * Multipage Tiff files can now be read using "volread()" to obtain
    the image data as one array.
  * Updated the ffmpeg executables that imageio provides.
  * The ffmpeg format can now also use the ffmpeg exe provided by the
    ffmpeg conda package ("conda install ffmpeg -c conda-forge").
  * Fixes to ffmpeg format in general.
  * Improve docs and rounding in animated GIF duration.
  * Fix for setting number of loops in animated GIF.
  * Fixes for transparent images in Pillow.
  * Fixes for float indexing that is disallowed in new Numpy
    (Freeimage plugin).
  * Fix for using missing "close()" on Pillow images.
  * Updated version of tiffile plugin.
* Sat Mar  3 2018 jengelh@inai.de
- Update descriptions.
* Wed May 17 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix source URL
- Update to version 2.1.2
  Large number of changes, see:
  https://imageio.readthedocs.io/en/latest/releasenotes.html#version-2-1-2-02-02-2017
* Tue Dec  9 2014 toddrme2178@gmail.com
- Initial version
